@@ -12,15 +12,18 @@ from ...en.any.international_phone_number import PATTERN_INT_PHONE
 
 PII_TASKS = [
     {
-        "pii": PiiEnum.PHONE_NUMBER,
-        "type": "regex",
+        "class": "regex",
         "task": PATTERN_INT_PHONE,
         "name": "international phone number",
-        "doc": "detect phone numbers that use international notation. Uses language context",
-        "context": {
-            "value": ["tf", "teléfono", "telefono"],
-            "width": [16, 0],
-            "type": "word",
-        },
+        "doc": "detect phone numbers using international notation",
+        "pii": {
+            "type": PiiEnum.PHONE_NUMBER,
+            "subtype": "international",
+            "context": {
+                "value": ["tf", "teléfono", "telefono"],
+                "width": [16, 0],
+                "type": "word",
+            },
+        }
     }
 ]
